#!/bin/ksh
#############################################################################
## Licensed Materials - Property of IBM
##
## Governed under the terms of the International
## License Agreement for Non-Warranted Sample Code.
##
## (C) COPYRIGHT International Business Machines Corp. 2008, 2012
## All Rights Reserved.
##
## US Government Users Restricted Rights - Use, duplication or
## disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
##
##   Title: pedigree-was-cfg.sh	
##   Description: Configures WAS resources and installs applications
##   Usage: pedigree-was-cfg.sh -clean | -all | -docped 
##          -clean   cleans the WAS config
##          -all     create configuration and install app for ePedigree and Document Pedigree  
##	     -docped  create configuration and install app for Document Pedigree
##  -was_admin_user optional argument if WAS is security enabled
##  -was_admin_password optional argument if was_admin_user needs to be passed
##  -was_runas_user optional argument to use was_runas_user
##  -help prints the usage
##          by default create configuration and install app for ePedigree
##
#############################################################################

#
# setup solution environment
#
SCRIPT_DIR=`dirname ${0}`
if [ -f ${SCRIPT_DIR}/pedigree-env.sh ]; then
	. ${SCRIPT_DIR}/pedigree-env.sh
else
	#"$0 : File not found ${SCRIPT_DIR}/pedigree-env.sh"
	exit 1
fi
PLATFORM=`/bin/uname`
if [ "$PLATFORM" = "SunOS" ];then
	AWK="awk -F."
else
	AWK="awk -F ".""
fi


usage()
{
  usage="\n\
  $0 '[options]'\n\
  Options:\n\
  -clean   cleans the WAS config \n\
  -all     create configuration and install app for ePedigree and Document Pedigree \n\
  -docped  create configuration and install app for Document Pedigree only \n\
  -was_admin_user optional argument if WAS is security enabled \n\
  -was_admin_password optional argument if was_admin_user needs to be passed \n\
  -was_runas_user optional argument to use was_runas_user \n\
  -help prints the usage\n\
  none     create configuration and install app for ePedigree only"
  echo -e "Usage: $usage"
  return 0
}

#
# Start WAS and WAS capture
# $1 = if 'restart' then first stop WAS then start
#
startWAS()
{

	if [ "$1" = "restart" ]; then
		${STOP_RFIDIC} -components=was
	fi
	echo_message FEAT05206I "$0" "WebSphere"
	#"${0}: starting WebSphere..."
	run_command ${START_RFIDIC} -components=was
	#"${0}: starting WebSphere Capture..."
	echo_message FEAT05206I "$0" "WebSphere Capture"
	run_command ${START_RFIDIC} -components=capture
}

stopWAS(){
   if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
        ${WAS_HOME}/bin/stopServer.sh ${SERVERNAME} -username $was_admin_user -password $was_admin_password
   else
        ${WAS_HOME}/bin/stopServer.sh ${SERVERNAME}
   fi
   retCode=$?
   if [ "$retCode" != 0 -a "$retCode" != 246 ];then
	 echo "The stopWAS command returned a non-zero code"
	 exit $retCode
   fi
}


### Main starts here #####

# CONFIG_OPTION = configure | unconfigure
CONFIG_OPTION=configure

if [ $# -gt 7 ]; then
    usage
    exitError $E_OPTERROR
else
	unset was_admin_user
	unset was_admin_password
	unset was_runas_user
	unset wasConfigDocped
	unset wasConfigEped
	wasConfigEped=1
	
    for item in $*
	do
		if [ `expr match "$item" '-clean'` != 0 ]; then
                  CONFIG_OPTION=unconfigure
	  		     wasConfigEped=1
	  		     wasConfigDocped=1
		elif [ `expr match "$item" '-was_admin_user'` != 0 ]; then
                  was_admin_user=`echo ${item#-was_admin_user=}`
		elif [ `expr match "$item" '-was_admin_password='` != 0 ]; then
        	    was_admin_password=`echo ${item#-was_admin_password=}`
		elif [ `expr match "$item" '-was_runas_user'` != 0 ]; then
                 was_runas_user=`echo ${item#-was_runas_user=}`
		elif [ `expr match "$item" '-all'` != 0 ]; then
                 wasConfigDocped=1		  
		elif [ `expr match "$item" '-docped'` != 0 ]; then
                 wasConfigDocped=1
		   wasConfigEped=0
		elif [ `expr match "$item" '-help'` != 0 ]; then
			usage
			exit
		else
			echo "Execute the script with one of the options as shown below"
            usage
            exitError $E_OPTERROR
        fi
    done
fi

if [ -z "$SERVERNAME" -o -z "$NODENAME" -o -z "$CELLNAME" -o -z "$QUEUE_MANAGER" -o -z "$DBMS_ALIAS" \
    -o -z "$DBMS_ADMIN_USER" -o -z "$DBMS_ADMIN_PWD" -o -z "$DBMS_DB_NAME" -o \
    -z "$HOSTNAME" ]; then

   echo_message FEAT05208I "SERVERNAME=\"$SERVERNAME\" NODENAME=\"$NODENAME\" CELLNAME=\"$CELLNAME\" \
 QUEUE_MANAGER=\"$QUEUE_MANAGER\" DBMS_ALIAS=\"$DBMS_ALIAS\" DBMS_ADMIN_USER=\"$DBMS_ADMIN_USER\" \
 DBMS_ADMIN_PWD=\"$DBMS_ADMIN_PWD\" DBMS_DB_NAME=\"$DBMS_DB_NAME\" HOSTNAME=\"$HOSTNAME\""

	# Please check the following files: ...
	echo_message FEAT05212I "  $RFIDIC_SOLDIR/bin/pedigree-env.sh"
	exit ${E_ENVERROR}
fi

getActualWASConfig


#
# Figure out users and passwords
#
if [ -n "$was_admin_user" ]; then
	if [ -z "$was_admin_password" ]; then
		# "Enter password for WebSphere Administrative user id \"${was_admin_user}\":"
		echo_message FEAT05200I "${was_admin_user}" 
		stty -echo
		read was_admin_password
		stty echo
		echo
	fi
	WSADMIN="${WAS_HOME}/bin/wsadmin.sh -profileName $PROFILENAME -conntype SOAP -user ${was_admin_user} -password ${was_admin_password} -wsadmin_classpath $CLASSPATH "
	STOP_RFIDIC="${RFIDIC_HOME}/bin/stopTS.sh -was_admin_user=${was_admin_user} -was_admin_password=${was_admin_password}"
else
	WSADMIN="${WAS_HOME}/bin/wsadmin.sh -profileName $PROFILENAME -wsadmin_classpath $CLASSPATH "
	STOP_RFIDIC="${RFIDIC_HOME}/bin/stopTS.sh"
fi

if [ -n "$was_runas_user" ]; then
	START_RFIDIC="${RFIDIC_HOME}/bin/startTS.sh -was_runas_user=${was_runas_user}"
else
	START_RFIDIC="${RFIDIC_HOME}/bin/startTS.sh"
fi
if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
     START_RFIDIC="$START_RFIDIC -was_admin_user=${was_admin_user} -was_admin_password=${was_admin_password}"
fi

checkPlatform

#Set the SOAP.requestTimeout to 0 ie No timeout 
asciiUpdate "$WAS_HOME/profiles/$PROFILENAME/properties/soap.client.props" 'com.ibm.SOAP.requestTimeout=180' "com.ibm.SOAP.requestTimeout=0"

if [ "$wasConfigEped" = "1" ]
then
# on a WebSphere instance where RFIDIC is deployed, the audit queue and connection 
# factory are created by $RFIDIC_HOME/bin/jacl/recreateAuditConfig.jacl, 
# called by rfidic-was-cfg.sh.
# On other systems, the audit needs to be manually setup prior to running this 
# script. For more info, please check $RFIDIC_HOME/bin/rfidic-was-cfg.sh.

# create datasource on existing provider
if [ "$DB_TYPE" = "ORACLE" ]; then
	# Determine the Oracle Version
		getDBVersion
		if [ `echo $DBversion | ${AWK} '{print($1)}'` = "11" ];then
			oraVersion="11g"
		else
			oraVersion="10g"
		fi

    run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION \
        $SERVERNAME $DBMS_ALIAS $DBMS_ADMIN_USER $DBMS_ADMIN_PWD "RFIDIC Oracle JDBC Provider" \
        "Pedigree Data Source" "Epedigree Data Source" "Oracle Database Settings" \
        $DBMS_DB_NAME " " $DBMS_PORT $PEDIGREE_DB_HOST jdbc/ibm/epcis/pedigree/db \
        " " " " "false" $DB_TYPE 10 $ORACLE_JDBC_URL $oraVersion $NORFIDIC

    run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION \
        $SERVERNAME $DBMS_ALIAS $DBMS_ADMIN_USER $DBMS_ADMIN_PWD "RFIDIC Oracle JDBC XA Provider" \
        "Pedigree XA Data Source" "Epedigree XA Data Source" "Oracle Database Settings" \
        $DBMS_DB_NAME " " $DBMS_PORT $PEDIGREE_DB_HOST jdbc/ibm/epcis/pedigree/dbXA \
        " " " " "true" $DB_TYPE 40 $ORACLE_JDBC_URL $oraVersion $NORFIDIC
elif [ "$DB_TYPE" = "DB2" ]; then
    run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION \
        $SERVERNAME $DBMS_ALIAS $DBMS_ADMIN_USER $DBMS_ADMIN_PWD "RFIDIC DB2 JDBC Provider" \
        "Pedigree Data Source" "Epedigree Data Source" "DB2 Database Settings" \
        $DBMS_DB_NAME $DB2_SERVER $DBMS_PORT $PEDIGREE_DB_HOST jdbc/ibm/epcis/pedigree/db \
        " " " " "false" $DB_TYPE 10 " " " " $NORFIDIC

    run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateDatasource.jacl $CONFIG_OPTION \
        $SERVERNAME $DBMS_ALIAS $DBMS_ADMIN_USER $DBMS_ADMIN_PWD "RFIDIC DB2 JDBC XA Provider" \
        "Pedigree XA Data Source" "Epedigree XA Data Source" "DB2 Database Settings" \
        $DBMS_DB_NAME $DB2_SERVER $DBMS_PORT $PEDIGREE_DB_HOST jdbc/ibm/epcis/pedigree/dbXA \
        " " " " "true" $DB_TYPE 40 " " " " $NORFIDIC
else
	# database $DB_TYPE not supported
	echo_message FEAT05234E "$0" $DB_TYPE
	exit -1
fi

#
# Create JMS queue connection factories
#
	echo "Using the existing TS Queue Connection Factories..."

#
# Creating a Bus for doc pedigree service 'DocPedigreeServiceQueue'
# This will be common for both event pedigree and document pedigree
#

run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/createBus.jacl "unconfigure" $NODENAME $SERVERNAME $DOC_SERVICE_BUS_NAME "A Bus for doc pedigree service" DocPedigreeServiceQueue PedigreeServiceInputQueue
run_command rm -rf $WAS_HOME/profiles/default/databases/com.ibm.ws.sib/$NODENAME.$SERVERNAME-$DOC_SERVICE_BUS_NAME 
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/createBus.jacl $CONFIG_OPTION $NODENAME $SERVERNAME $DOC_SERVICE_BUS_NAME "A Bus for doc pedigree service" DocPedigreeServiceQueue PedigreeServiceInputQueue
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/pedigreeQueues.jacl $CONFIG_OPTION $CELLNAME $NODENAME $SERVERNAME $PEDIGREE_MQ_HOST DocPedigreeServiceQueue DocPedigreeServiceQueueConnFact jms/ibm/rfidic/docpedigree/OutQueue jms/ibm/rfidic/docpedigree/OutQueueFact DocPedigreeServiceAS jms/ibm/rfidic/docpedigree/serviceAS $DOC_SERVICE_BUS_NAME DocPedigreeServiceQueue 
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/pedigreeQueues.jacl $CONFIG_OPTION $CELLNAME $NODENAME $SERVERNAME $PEDIGREE_MQ_HOST PedigreeServiceInputQueue DocPedigreeServiceInputQueueConnFact jms/ibm/epcis/pedigree/ws jms/ibm/epcis/pedigree/wsCF  AsyncDocPedigreeServiceAS jms/ibm/epcis/pedigree/wsAS $DOC_SERVICE_BUS_NAME PedigreeServiceInputQueue


#
# Create the Master Data Change Notification Topic
# 
	echo "Using the existing TS Master Data Change Notification Topic..."

#
# Create the Master Data Change Notification Listener Port
#
LPName="ibmEpcisPedigreeMDMListener"
tcfJNDI="jms/ibm/epcis/TCF"
topicJNDI="jms/ibm/epcis/mdm/changeNotification"
State="STOP"
#State="START"
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateListener.jacl $CONFIG_OPTION \
	$SERVERNAME $NODENAME $CELLNAME $topicJNDI $LPName $tcfJNDI $State

#
# Create the Pedigree Event Queue
#
QName="ibmEpcisPedigreeEventQueue"
QDesc="Queue_for_Pedigree_Events"
Qjndi="jms/ibm/epcis/pedigree/eventQ"
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateMQQ.jacl $CONFIG_OPTION \
	$SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $QNAME_PEDIGREE_EVENT $QUEUE_MANAGER

#
# Create the Pedigree Event Listener Port
#
LPName="ibmEpcisPedigreeEventListener"
# AFK: Changed to use the existing TS connection factory
QCF="jms/ts/MQConnectionFactory"
Qjndi="jms/ibm/epcis/pedigree/eventQ"
State="STOP"
#State="START"
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateListener.jacl $CONFIG_OPTION \
	$SERVERNAME $NODENAME $CELLNAME $Qjndi $LPName $QCF $State
	
#
# Update transaction service configuration
#
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/updateTransactionSvcConf.jacl $SERVERNAME $NODENAME $CELLNAME
	
stopWAS
startWAS

#
# Install ear
#

run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION \
    $SERVERNAME $NODENAME $CELLNAME "$WAS_HOME/installableApps/com.ibm.epcis.pharma.pedigree.ear" \
    com.ibm.epcis.pharma.pedigreeEAR  "start"
    
## Pedigree UI EAR
run_command ${WSADMIN} -f $RFIDIC_HOME/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION \
    $SERVERNAME $NODENAME $CELLNAME "$WAS_HOME/installableApps/com.ibm.rfidic.pharma.epedigree.ui.ear" \
    com.ibm.rfidic.pharma.epedigree.uiEAR

echo "${0} - configuration script done"
fi
# This fi is for end of eventPed

if [ "$wasConfigDocped" = "1" ];then

# Remove the capture bus
# Not using the run_command for the few commands below because if the resources are not present already - the errors can be ignored.
${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/createBus.jacl "unconfigure" $NODENAME $SERVERNAME $DOC_CAPTURE_BUS_NAME "A Bus for doc pedigree capture" DocPedigreeCaptureQueue
rm -rf $WAS_HOME/profiles/default/databases/com.ibm.ws.sib/$NODENAME.$SERVERNAME-$DOC_CAPTURE_BUS_NAME
${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/pedigreeQueues.jacl "unconfigure" $CELLNAME $NODENAME $SERVERNAME $PEDIGREE_MQ_HOST DocPedigreeCaptureQueue DocPedigreeCaptureQueueConnFact jms/ibm/rfidic/docpedigree/InQueue jms/ibm/rfidic/docpedigree/InQueueFact DocPedigreeCaptureAS jms/ibm/rfidic/docpedigree/captureAS $DOC_CAPTURE_BUS_NAME DocPedigreeCaptureQueue
${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateMQQ.jacl "unconfigure" $SERVERNAME $NODENAME $CELLNAME "docPedigreeMQDest" "Queue for DocPedigree" jms/ibm/rfidic/docpedigree/InQueue $DOCPEDIGREE_QUEUE $QUEUE_MANAGER
${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateMQQCF.jacl "unconfigure" $SERVERNAME $NODENAME $CELLNAME "docPedigreeQCF" "DocPedigree Queue Connection Factory" jms/ibm/rfidic/docpedigree/InQueueFact $PEDIGREE_MQ_HOST $MQ_LSR_PORT $QUEUE_MANAGER RFIDICMQAlias "true" $MQ_USER $MQ_USER_PASSWORD
${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateListener.jacl "unconfigure" $SERVERNAME $NODENAME $CELLNAME jms/ibm/rfidic/docpedigree/InQueue docPedigreeMQListener jms/ibm/rfidic/docpedigree/InQueueFact STOP


# Create SI Bus and needed queues
if [ "$CAPTURE_TYPE" = "HTTP" ];then
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/createBus.jacl $CONFIG_OPTION $NODENAME $SERVERNAME $DOC_CAPTURE_BUS_NAME "A Bus for doc pedigree capture" DocPedigreeCaptureQueue
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/pedigreeQueues.jacl $CONFIG_OPTION $CELLNAME $NODENAME $SERVERNAME $PEDIGREE_MQ_HOST DocPedigreeCaptureQueue DocPedigreeCaptureQueueConnFact jms/ibm/rfidic/docpedigree/InQueue jms/ibm/rfidic/docpedigree/InQueueFact DocPedigreeCaptureAS jms/ibm/rfidic/docpedigree/captureAS $DOC_CAPTURE_BUS_NAME DocPedigreeCaptureQueue
fi

# Creating WebSphere Queue destination , Queue connection factory , listener 

if [ "$CAPTURE_TYPE" = "MQ" ];then

	QName="docPedigreeMQDest"
	QDesc="Queue for DocPedigree"
	Qjndi="jms/ibm/rfidic/docpedigree/InQueue"
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateMQQ.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QName" "$QDesc" $Qjndi $DOCPEDIGREE_QUEUE $QUEUE_MANAGER
	
	QCFName="docPedigreeQCF"
	QCFDesc="DocPedigree Queue Connection Factory" 
	QCFjndi="jms/ibm/rfidic/docpedigree/InQueueFact"
	MQHost=$PEDIGREE_MQ_HOST
	MQPort=$MQ_LSR_PORT
	MQAlias="RFIDICMQAlias"
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateMQQCF.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME "$QCFName" "$QCFDesc" $QCFjndi $MQHost $MQPort $QUEUE_MANAGER $MQAlias "true" $MQ_USER $MQ_USER_PASSWORD $NORFIDIC
		
	LPjndi="jms/ibm/rfidic/docpedigree/InQueue"
	LPName="docPedigreeMQListener"
	QCF="jms/ibm/rfidic/docpedigree/InQueueFact"
	#State="START"
	State="STOP"
	run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateListener.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $LPjndi $LPName $QCF $State
		
	#echo "WebSphere Queue destination , Queue connection factory , listener created successfully"
	echo_message PEDI06812I
fi

# Install the application
START_OPTION=no_start
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/reinstallApplication.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $DOC_PEDIGREE_CAPTURE_APP_LOCATION $DOC_PEDIGREE_CAPTURE_APP_NAME $START_OPTION $CAPTURE_TYPE

# Creating the scheduler
SCHEDULER_NAME=DocumentClientScheduler
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/recreateScheduler.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $SCHEDULER_NAME jdbc/ibm/epcis/pedigree/dbXA $DBMS_ALIAS 10 CLIENTTIMER_ PedigreeWorkManager pedigree/wm
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/createSchedTables.jacl $CONFIG_OPTION $SERVERNAME $NODENAME $CELLNAME $SCHEDULER_NAME

# Updating EJB Container's timer service with this scheduler
run_command ${WSADMIN} -f $RFIDIC_SOLDIR/bin/jacl/modifyTimerService.jacl $SERVERNAME $NODENAME $CELLNAME $SCHEDULER_NAME

# This restart is required - because only the DocumentEAR can be started and user can be added to it
# only after a complete restart.Else the listener will not be found
$STOP_RFIDIC -components=WAS,CAPTURE
$START_RFIDIC -components=WAS,CAPTURE
echo_message PEDI06814I
if [ "$CONFIG_OPTION" = "configure" ];then
	if [ -n "$was_admin_user" -a -n "$was_admin_password" ];then
		credentials="-was_admin_user=$was_admin_user -was_admin_password=$was_admin_password"
    fi
	run_command ${PEDIGREE_HOME}/bin/setPedWebServicesBindingInfoMain.sh $credentials
fi

fi
#This fi is for end of DocPed

exit 0
